@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import logging
 import threading
 import time
 import typing
@@ -5,14 +8,16 @@ import typing
 if typing.TYPE_CHECKING:
     from flagsmith import Flagsmith
 
+logger = logging.getLogger(__name__)
+
 
 class EnvironmentDataPollingManager(threading.Thread):
     def __init__(
         self,
-        *args,
-        main: "Flagsmith",
+        *args: typing.Any,
+        main: Flagsmith,
         refresh_interval_seconds: typing.Union[int, float] = 10,
-        **kwargs
+        **kwargs: typing.Any,
     ):
         super(EnvironmentDataPollingManager, self).__init__(*args, **kwargs)
         self._stop_event = threading.Event()
@@ -27,5 +32,5 @@ class EnvironmentDataPollingManager(threading.Thread):
     def stop(self) -> None:
         self._stop_event.set()
 
-    def __del__(self):
+    def __del__(self) -> None:
         self._stop_event.set()
